#===============================================================================
# check_motifs.py
#===============================================================================

"""Check motifs"""




# Imports ======================================================================

import itertools
import re

from argparse import ArgumentParser
from pybedtools import BedTool
from dismotif.var_to_hg19 import generate_vars_from_file, var_to_hg19



# Constants ====================================================================

RSID_REGEX = re.compile('rs[1-9][0-9]+$')




# Functions ====================================================================

def parse_arguments():
    parser = ArgumentParser(description='disrupted motifs')
    parser.add_argument(
        'variants',
        metavar='<rsid or file>',
        nargs='+',
        help='Variants or list of variants'
    )
    args = parser.parse_args()
    args.variants = list(
        itertools.chain.from_iterable(
            (v,) if RSID_REGEX.match(v) else generate_vars_from_file(v)
            for v in args.variants
        )
    )
    return args

def main():
    args = parse_arguments()
    print(args.variants)
    print(BedTool(r for *r, f in var_to_hg19(args.variants) if len(r) == 4))


#!/usr/bin/env python3

import os
import sys
import math

infile = sys.argv[1]

def load_motif(motif):
	motif_file = os.path.join('/home/joshchiou/references/combined_motifs/', motif + '.db')
	pwm = {}
	with open(motif_file) as mf:
		ls = mf.read().splitlines()
		for i,l in enumerate(ls):
			n = i+1
			bases = list(map(float, l.split(' ')))
			pwm[n] = {'A':bases[0], 'C':bases[1], 'G':bases[2], 'T':bases[3]} 
	return pwm

def calc_entropy(pwm, vpos):
	entropy = 0
	for freq in pwm[vpos].values():
		if freq > 0:
			entropy += freq * math.log2(freq)
	if entropy < 0:
		entropy *= -1
	return entropy

with open(infile) as f:
	for line in f:
		fields = line.rstrip('\n').split('\t')
		mstart, mend = int(fields[5]) + 1, int(fields[6]) + 1
		mname = fields[7]
		mstrand = fields[9]
		vpos = int(fields[2])
		pwm = load_motif(mname)
		if mstrand == '+':
			vmpos = vpos - mstart + 1
		elif mstrand == '-':
			vmpos = mend - vpos
		entropy = calc_entropy(pwm, vmpos)
		fields.append(str(entropy))
		print('\t'.join(fields))




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='dismotif',
    version='0.0.2',
    author='Anthony Aylward, Joshua Chiou',
    author_email='aaylward@eng.ucsd.edu',
    description='disrupted motifs',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/anthony-aylward/chipseqpeaks.git',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    install_requires=['pybedtools','pyhg19'],
    entry_points={
        'console_scripts': ['dismotif=dismotif.check_motifs:main',]
    },
    include_package_data=True
)



#!/usr/bin/env python3
#===============================================================================
# var_to_hg19.py
#===============================================================================

# Imports ======================================================================

import itertools
import pyhg19
import re
import sys

from argparse import ArgumentParser



# Constants ====================================================================

RSID_REGEX = re.compile('rs[1-9][0-9]+$')




# Functions ====================================================================

def generate_vars_from_file(file):
	  with open(file) as f:
		    yield from f.read().splitlines()


def var_to_hg19(*variants):
    for r in variants:
        try:
            coord = pyhg19.coord(r)
            yield ('chr'+ str(coord.chr), coord.pos-1, coord.pos, r, sys.stdout)
        except:
            yield (r, sys.stderr)


def parse_arguments():
    parser = ArgumentParser(description='vars to hg19')
    parser.add_argument(
        'variants',
        metavar='<rsid or file>',
        nargs='+',
        help='Variants or list of variants'
    )
    args = parser.parse_args()
    args.variants = list(
        itertools.chain.from_iterable(
            (v,) if RSID_REGEX.match(v) else generate_vars_from_file(v)
            for v in args.variants
        )
    )
    return args


def main():
    args = parse_arguments()
    for *r, f in var_to_hg19(args.variants):
        print('\t'.join(r), file=f)




# Execute ======================================================================

if __name__ == '__main__':
    main()
